// extras
int bed = 0; // 0 = no one, 1 = in
int state = 0; // 
int vibrate = 0; //
int counter = 0; //
int snoozeCount = 0; //

// bed flex sensor
const int FLEX_PIN1 = A0; // Pin connected to voltage divider output
const float VCC1 = 5; // Measured voltage of Ardunio 5V line
const float R_DIV1 = 47500.0; // Measured resistance of 3.3k resistor
const float STRAIGHT_RESISTANCE1 = 37300.0; // resistance when straight
const float BEND_RESISTANCE1 = 90000.0; // resistance at 90 deg

// transducer 
int speaker = 5;
int speaker2 = 6;

// audio potentiometer
int pot = 2;

// bed: snooze button
int orangeButtonPin = 2;
int orangeButtonStatus = 0;

// kitchen: sleeper status
int KitchenLED = 13;

// kitchen: sleeper alarm
int redButtonPin = 3; // Kitchen

void setup() {
  // put your setup code here, to run once:
  
    //SERIAL
    Serial.begin(9600);

    // INPUTS
    pinMode(orangeButtonPin, INPUT); // snooze
    pinMode(redButtonPin, INPUT); // kitchen wake-up
    pinMode(FLEX_PIN1, INPUT); // in bed sensor
    pinMode(pot, INPUT); //audio representation

    // OUTPUTS
    pinMode(KitchenLED, OUTPUT); // sleep status in kitchen
    pinMode(speaker, OUTPUT); // transducer
    pinMode(speaker2, OUTPUT); // transducer

    // INTERRUPTS
    attachInterrupt(digitalPinToInterrupt(redButtonPin), KitchenWake, CHANGE);
    attachInterrupt(digitalPinToInterrupt(orangeButtonPin), BedSnooze, CHANGE); 
}

void loop() {
  // put your main code here, to run repeatedly:
  
// READ DATA
  // STATE
    Serial.print("bed is ");
    Serial.println(bed);
    Serial.print("state is ");
    Serial.println(state);
    Serial.print("counter is ");
    Serial.println(counter);

  // FLEX SENSOR
    int flexADC1 = analogRead(FLEX_PIN1);
    float flexV1 = flexADC1 * VCC1 / 1023.0;
    float flexR1 = R_DIV1 * (VCC1 / flexV1 - 1.0);
    float angle1 = map(flexR1, STRAIGHT_RESISTANCE1, BEND_RESISTANCE1,
                       0, 90.0);

  // POTENTIOMETER
    int audio = analogRead(pot);
    Serial.print("audio is ");
    Serial.println(audio);
    
  // COUNTER
    counter++;

// ASSIGN STATE
  // Flex Sensor
    if(angle1 == -44){
      bed = 0; // no one is in bed
      vibrate = 0;
    }

    if(angle1 != -44){
      bed = 1; // someone is in bed
    }

  // Audio Sensor
    if(audio > 300 && audio < 800){
      state = 2; // Sensor hears alarm or someone yelling (?)
    }

    if(audio > 799){
      state = 4; // Sensor hears alarm or someone yelling (?)
    }
    
  // Counter (Time Alarm Simulator)
    if(snoozeCount == 0 && counter > 500){
      state = 2; // Second alarm to get up for work/school
    }

    if(snoozeCount == 1 && counter > 500){
      state = 3; // Second alarm to get up for work/school
    }

    if(snoozeCount == 2 && counter > 500){
      state = 4; // Second alarm to get up for work/school
    }

    if(snoozeCount == 3){
      state = 5; // Turn alarms off
    }

      
// STATE MACHINE  
  // Nothing
    if(bed == 0 && state == 0){
      digitalWrite(KitchenLED, LOW);
      // transducer = none
    }

    if(bed == 1 && state == 0){
      digitalWrite(KitchenLED, HIGH);
      // transducer = none
    }
    
  // Alarm goes off --> High level vibration
    if(bed == 0 && state == 1){
      // transducer off
      digitalWrite(KitchenLED, LOW); 
    }
    
    if(bed == 1 && state == 1){
      // transducer severe level
      tone(speaker,1000);
      digitalWrite(KitchenLED, HIGH);
      delay(1000);
      digitalWrite(KitchenLED, LOW);
      delay(1000);  
    }  
      
  // Wake-up call for school or work
    if(bed == 0 && state == 2){
      // transducer off
      digitalWrite(KitchenLED, LOW);
    }
    
    if(bed == 1 && state == 2){
      // transducer on medium level
      noTone(speaker);
      tone(speaker2,500,500);
      digitalWrite(KitchenLED, HIGH);
      delay(1000);
      digitalWrite(KitchenLED, LOW);
      delay(1000); 
    }

  // Second wake-up call for school or work
    if(bed == 0 && state == 3){
      // transducer off
      digitalWrite(KitchenLED, LOW);
    }
    
    if(bed == 1 && state == 3){
      // transducer on high level
      noTone(speaker);
      tone(speaker2,800,1000);
      digitalWrite(KitchenLED, HIGH);
      delay(500);
      digitalWrite(KitchenLED, LOW);
      delay(500); 
    }

  // Last wake-up call for school or work
    if(bed == 0 && state == 4){
      // transducer off
      digitalWrite(KitchenLED, LOW);
    }
    
    if(bed == 1 && state == 4){
      // transducer on severe level
      tone(speaker,800,2000);
      tone(speaker2,800,2000);
      digitalWrite(KitchenLED, HIGH);
      delay(100);
      digitalWrite(KitchenLED, LOW);
      delay(100); 
    }

  // Snoozed all alarms
    if(bed == 0 && state == 5){
      // transducer off
      digitalWrite(KitchenLED, LOW);
    }
    
    if(bed == 1 && state == 5){
      // transducer off
      digitalWrite(KitchenLED, HIGH);
    }

  // Mom is waking you up
    if(bed == 0 && state == 11){
      // transducer off
      digitalWrite(KitchenLED, LOW);
    }
    
    if(bed == 1 && state == 11){
      // transducer on high level
      tone(speaker,600, 250);
      noTone(speaker2);
      digitalWrite(KitchenLED, HIGH);
      delay(500);
      digitalWrite(KitchenLED, LOW);
      delay(500); 
    }

}

void KitchenWake() {
  state=11; //only increases one with each button push
  snoozeCount = 0;
}

void BedSnooze() {
  counter = 0;
  snoozeCount++;
}
